"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRuntimeStore = exports.createStore = void 0;
/**
 * @todo rename this to imageDataStore
 */
function createStore(initialState = {}) {
    let state = initialState;
    return {
        /**
         * returns the current state
         */
        getState() {
            return state;
        },
        /**
         * Get the state for a particular site or default to en empty object if it does not yet exist
         *
         * @param siteID
         */
        getStateBySiteID(siteID) {
            return state[siteID] || { imageData: {} };
        },
        /**
         * Merges in new state with existing state
         *
         * @param update new state
         */
        setState(newState) {
            state = Object.assign(Object.assign({}, state), newState);
        },
        /**
         * remove a site by id
         *
         * @param siteID
         */
        deleteSiteData(siteID) {
            delete state[siteID];
        },
        /**
         * Merges in new SiteData with existing SiteData or
         * creates a new entry for that SiteData
         *
         * @param siteID
         * @param newState
         */
        setStateBySiteID(siteID, newState) {
            state = Object.assign(Object.assign({}, state), { [siteID]: Object.assign(Object.assign({}, (state[siteID] || {})), newState) });
        },
        /**
         * Merges in new image data for a single image associated with a site
         *
         * @param siteID
         * @param imageID
         * @param newState
         */
        setStateByImageID(siteID, imageID, newState) {
            var _a, _b, _c;
            state = Object.assign(Object.assign({}, state), { [siteID]: Object.assign(Object.assign({}, state[siteID]), { imageData: Object.assign(Object.assign({}, (_a = state[siteID]) === null || _a === void 0 ? void 0 : _a.imageData), { [imageID]: Object.assign(Object.assign({}, (_c = (_b = state[siteID]) === null || _b === void 0 ? void 0 : _b.imageData) === null || _c === void 0 ? void 0 : _c[imageID]), newState) }) }) });
        },
    };
}
exports.createStore = createStore;
function createRuntimeStore(initialState = {}) {
    const state = initialState;
    return {
        /**
         * returns the current state
         */
        getState() {
            return state;
        },
        /**
         * get the current state by siteID
         *
         * @param siteID
         */
        getStateBySiteID(siteID) {
            return state[siteID] || {};
        },
        /**
         * set if a compression process should be canceled
         *
         * @param siteID
         * @param cancelCompression
         */
        setCancelCompressionBySiteID(siteID, cancelCompression) {
            if (!state[siteID]) {
                state[siteID] = {};
            }
            state[siteID].cancelCompression = cancelCompression;
        },
    };
}
exports.createRuntimeStore = createRuntimeStore;
//# sourceMappingURL=createStore.js.map