"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.restoreImageFromBackupFactory = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const glob_1 = require("glob");
const glob_escape_1 = __importDefault(require("glob-escape"));
const constants_1 = require("../constants");
const errorReporting_1 = require("./errorReporting");
const utils_1 = require("./utils");
const types_1 = require("../types");
function restoreImageFromBackupFactory(serviceContainer, store) {
    return function (siteId, imageId) {
        return __awaiter(this, void 0, void 0, function* () {
            /**
             * Return a properly formatted error response, update the in-memory store and write that value to disk
             */
            const formatErrorReplyAndSetState = () => {
                store.setStateByImageID(siteId, imageId, {
                    revertToBackupStatus: types_1.RevertToBackupStatus.FAILURE,
                });
                (0, utils_1.saveImageDataToDisk)(store, serviceContainer);
                return {
                    success: false,
                };
            };
            const state = store.getStateBySiteID(siteId);
            const fileData = state.imageData[imageId];
            const site = serviceContainer.siteData.getSite(siteId);
            const { filePath } = fileData;
            // path to the root of the site's backup dir
            const baseBackupDirPath = path_1.default.join(site.longPath, constants_1.BACKUP_DIR_NAME);
            const imageBackupPath = filePath.replace(path_1.default.join(site.paths.webRoot, 'wp-content'), baseBackupDirPath);
            const { dir, name, ext } = path_1.default.parse(imageBackupPath);
            const globMatcher = `${(0, glob_escape_1.default)(`${dir}/${name}`)}?( \\([1-9]*\\))${ext}`;
            let matches;
            try {
                matches = glob_1.glob.sync(globMatcher);
            }
            catch (err) {
                (0, errorReporting_1.reportRestoreBackupFailure)(err);
            }
            if (!matches || matches.length === 0) {
                const errorMessage = 'No backups found for this image';
                (0, errorReporting_1.reportRestoreBackupFailure)(errorMessage);
                return formatErrorReplyAndSetState();
            }
            let mostRecentBackup;
            let mostRecentTimeStamp = 0;
            for (const match of matches) {
                const { birthtimeMs } = fs_extra_1.default.statSync(match);
                if (birthtimeMs > mostRecentTimeStamp) {
                    mostRecentTimeStamp = birthtimeMs;
                    mostRecentBackup = match;
                }
            }
            try {
                fs_extra_1.default.copySync(mostRecentBackup, filePath);
            }
            catch (err) {
                (0, errorReporting_1.reportRestoreBackupFailure)(err);
                return formatErrorReplyAndSetState();
            }
            store.setStateByImageID(siteId, imageId, {
                compressedImageHash: null,
                compressedSize: null,
                errorMessage: null,
                revertToBackupStatus: types_1.RevertToBackupStatus.SUCCESS,
            });
            (0, utils_1.saveImageDataToDisk)(store, serviceContainer);
            return {
                success: true,
            };
        });
    };
}
exports.restoreImageFromBackupFactory = restoreImageFromBackupFactory;
//# sourceMappingURL=restoreFromBackup.js.map