"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.scanImagesFactory = void 0;
/* eslint-disable @typescript-eslint/ban-ts-comment */
const path_1 = __importDefault(require("path"));
const LocalMain = __importStar(require("@getflywheel/local/main"));
const utils_1 = require("./utils");
const constants_1 = require("../constants");
const errorReporting_1 = require("./errorReporting");
/**
 * Scans a site's wp-content dir for images
 * Currently only supports jpeg
 *
 * @param siteID
 *
 * @returns ImageData[]
 */
function scanImagesFactory(serviceContainer, imageDataStore) {
    return function (siteID) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                (0, errorReporting_1.reportScanRequest)(siteID);
                const site = serviceContainer.siteData.getSite(siteID);
                let siteData = imageDataStore.getStateBySiteID(siteID);
                const imageData = siteData.imageData || {};
                if (!site) {
                    /**
                     * @todo does passing the error object here translate correctly to the UI?
                     */
                    serviceContainer.sendIPCEvent(constants_1.IPC_EVENTS.SCAN_IMAGES_FAILURE, siteID, new Error('Site not found!'));
                    return;
                }
                siteData = imageDataStore.getStateBySiteID(siteID);
                /**
                 * @todo - remove @ts-ignore once the new Local api changes are published
                 */
                // @ts-ignore
                const childProcess = LocalMain.workerFork(path_1.default.join(__dirname, 'scanImagesProcess'));
                /**
                 * @todo - remove @ts-ignore once the new Local api changes are published
                 */
                // @ts-ignore
                const processMessageHelper = LocalMain.childProcessMessagePromiseFactory(childProcess);
                /**
                 * @todo - remove @ts-ignore once the new Local api changes are published
                 */
                // @ts-ignore
                const filePaths = yield processMessageHelper('get-file-paths', {
                    webRoot: site.paths.webRoot,
                });
                /**
                 * @todo - remove @ts-ignore once the new Local api changes are published
                 */
                // @ts-ignore
                const updatedImageData = yield processMessageHelper('get-image-stats', {
                    filePaths,
                    imageData,
                });
                const nextSiteData = Object.assign(Object.assign({}, siteData), { imageData: updatedImageData, lastScan: Date.now() });
                imageDataStore.setStateBySiteID(siteID, nextSiteData);
                (0, utils_1.saveImageDataToDisk)(imageDataStore, serviceContainer);
                serviceContainer.sendIPCEvent(constants_1.IPC_EVENTS.SCAN_IMAGES_COMPLETE, siteID, nextSiteData);
                (0, errorReporting_1.reportScanSuccess)(siteID, filePaths.length);
            }
            catch (error) {
                (0, errorReporting_1.reportScanFailure)(siteID, error);
                return error;
            }
        });
    };
}
exports.scanImagesFactory = scanImagesFactory;
//# sourceMappingURL=scanImages.js.map