"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getImageStats = exports.scanImages = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const utils_1 = require("./utils");
const scanImages = (payload) => __awaiter(void 0, void 0, void 0, function* () {
    const { webRoot } = payload;
    const filePaths = yield (0, utils_1.getImageFilePaths)(webRoot);
    return filePaths;
});
exports.scanImages = scanImages;
const getImageStats = (payload) => __awaiter(void 0, void 0, void 0, function* () {
    const { filePaths, imageData } = payload;
    return yield filePaths.reduce((imageDataAccumulator, filePath) => __awaiter(void 0, void 0, void 0, function* () {
        const fileSize = fs_extra_1.default.statSync(filePath).size;
        const fileHash = yield (0, utils_1.getFileHash)(filePath);
        let compressedImage = (0, utils_1.getImageIfCompressed)(fileHash, imageData);
        if (compressedImage) {
            return Object.assign(Object.assign({}, (yield imageDataAccumulator)), { [compressedImage.originalImageHash]: compressedImage });
        }
        return Object.assign(Object.assign({}, (yield imageDataAccumulator)), { [fileHash]: {
                originalImageHash: fileHash,
                filePath,
                originalSize: fileSize,
            } });
    }), Promise.resolve({}));
});
exports.getImageStats = getImageStats;
function processSafeSend(name) {
    return (payload) => {
        var _a;
        (_a = process.send) === null || _a === void 0 ? void 0 : _a.call(process, { name, payload });
    };
}
process.on('message', (message) => __awaiter(void 0, void 0, void 0, function* () {
    const { name, payload } = message;
    const reply = processSafeSend(name);
    if (name === 'get-file-paths') {
        reply(yield (0, exports.scanImages)(payload));
    }
    if (name === 'get-image-stats') {
        reply(yield (0, exports.getImageStats)(payload));
    }
}));
//# sourceMappingURL=scanImagesProcess.js.map