"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSiteFullBackupPath = exports.getImageIfCompressed = exports.getImageFilePaths = exports.getImageFilePathsHelper = exports.getFileHash = exports.saveImageDataToDisk = exports.getSupportedFileExtensions = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const recursive_readdir_1 = __importDefault(require("recursive-readdir"));
const md5_1 = __importDefault(require("md5"));
const constants_1 = require("../constants");
/**
 * Utility to centralize the file extensions Image Optimizer supports
 */
const getSupportedFileExtensions = () => [
    '.jpg',
    '.jpeg',
];
exports.getSupportedFileExtensions = getSupportedFileExtensions;
function saveImageDataToDisk(imageDataStore, serviceContainer) {
    serviceContainer.userData.set(constants_1.COMPRESSED_IMAGE_DATA_FILE_NAME, Object.assign({}, imageDataStore.getState()));
}
exports.saveImageDataToDisk = saveImageDataToDisk;
function getFileHash(filePath) {
    return new Promise((resolve, reject) => {
        fs_extra_1.default.readFile(filePath, (err, buf) => {
            if (err) {
                reject(err);
            }
            resolve((0, md5_1.default)(buf));
        });
    });
}
exports.getFileHash = getFileHash;
/**
 * Get all JPG's recursively given a directly
 *
 * @param contentPath
 */
function getImageFilePathsHelper(contentPath) {
    return __awaiter(this, void 0, void 0, function* () {
        // ignore all files that aren't JPG's.
        // Directories must return false so that they won't be ignored. If they are ignored,
        // they will not be traversed
        const fileFilter = (file, stats) => {
            var _a;
            const ext = (_a = path_1.default.extname(file)) === null || _a === void 0 ? void 0 : _a.toLowerCase();
            return !(0, exports.getSupportedFileExtensions)().includes(ext) && !stats.isDirectory();
        };
        // if the directory doesn't exist, there aren't any files paths to retrieve
        if (!fs_extra_1.default.existsSync(contentPath)) {
            return new Promise((resolve) => resolve([]));
        }
        return new Promise((resolve, reject) => (0, recursive_readdir_1.default)(contentPath, [fileFilter], (err, files) => {
            if (err) {
                reject(err);
                return;
            }
            resolve(files);
        }));
    });
}
exports.getImageFilePathsHelper = getImageFilePathsHelper;
/**
 * Get all JPG's for wp-content/uploads
 *
 * @param site
 */
function getImageFilePaths(webRoot) {
    return __awaiter(this, void 0, void 0, function* () {
        return getImageFilePathsHelper(path_1.default.join(webRoot, 'wp-content', 'uploads'));
    });
}
exports.getImageFilePaths = getImageFilePaths;
/**
 * Given an MD5 hash of an image, returns wether or not this image is an original copy or has previously been
 * compressed by Local
 *
 * @param fileHash
 * @param imageData
 */
function getImageIfCompressed(fileHash, imageData) {
    return Object.values(imageData).find((data) => data.compressedImageHash === fileHash);
}
exports.getImageIfCompressed = getImageIfCompressed;
function getSiteFullBackupPath(siteId, site) {
    return path_1.default.join(site.longPath, constants_1.BACKUP_DIR_NAME);
}
exports.getSiteFullBackupPath = getSiteFullBackupPath;
//# sourceMappingURL=utils.js.map