import * as React from 'react';
import { FunctionGeneric } from '../../../common/structures/Generics';
import { TooltipProps } from '../../overlays/Tooltip/Tooltip';
export interface IMenuItem {
    /** Color for a textbutton item (not a separator) */
    color?: 'red' | 'none';
    /** Classname to add to the item component */
    className?: string;
    /** Will be rendered next to the label in the item's textButton */
    content?: React.ReactNode;
    /** Text to show in the item's TextButton */
    label?: string;
    /** Function to run when clicking the item - not run for items with submenus or separators */
    onClick?: FunctionGeneric;
    /** Set to false for a disabled textButton */
    enabled?: boolean;
    /** Available item types, checkbox will be styled with a check */
    type?: 'normal' | 'separator' | 'checkbox';
    /** Determines check icon for checkbox type items */
    checked?: boolean;
    /** Array of IMenuItem items that will recursively render a submenu to the side */
    submenu?: IMenuItem[];
}
export interface IContextMenuProps extends Omit<TooltipProps, 'content' | 'useClickInsteadOfHover' | 'ref'> {
    /** className for the list items' container */
    classNameList?: string;
    /** className for an individual list item */
    classNameListItem?: string;
    /** array of menu items */
    items: IMenuItem[];
    /** whether to have background behind 3 dots - set to false for low key 3 dot dropdowns */
    noBG?: boolean;
    /** whether to have background behind 3 dots on hover only */
    bgOnHover?: boolean;
    /** Private property used to render submenus recursively, should be no need to set this */
    isSubmenu?: boolean;
    /** Private property used to render submenus recursively, should be no need to set this */
    parentMenuId?: string;
}
declare const ContextMenu: {
    (props: IContextMenuProps): React.JSX.Element;
    defaultProps: Partial<IContextMenuProps>;
};
export default ContextMenu;
//# sourceMappingURL=ContextMenu.d.ts.map