import * as React from 'react';
import { Options } from '@popperjs/core/lib/modifiers/arrow';
import { Options as OffsetOptions } from '@popperjs/core/lib/modifiers/offset';
import IReactComponentProps from '../../../common/structures/IReactComponentProps';
import { FunctionGeneric } from '../../../common/structures/Generics';
export interface TooltipProps extends IReactComponentProps {
    /** the content that should show the tooltip upon the user's mouse entering it * */
    content?: React.ReactElement;
    /** whether to force the tooltip to show and ignore mouse events * */
    forceShow?: boolean;
    /** the number of milliseconds to delay hiding the tooltip after the user's mouse leaves this component * */
    hideDelay?: number;
    /** hide the tooltip arrow */
    hideArrow?: boolean;
    /** Additional popper arrow modifier */
    popperArrowModifier?: Partial<Options>;
    /** Additional popper offset modifier to reposition the popper tooltip [position's direction, perpendicular direction] */
    popperOffsetModifier?: Partial<OffsetOptions>;
    /** className to tweak popper container styles */
    popperContainerClassName?: string;
    /** className to tweak popper visual container styles */
    popperVisualContainerClassName?: string;
    /** the position/placement of the tooltip relative to the content * */
    position?: 'top' | 'top-start' | 'top-end' | 'right' | 'right-start' | 'right-end' | 'bottom' | 'bottom-start' | 'bottom-end' | 'left' | 'left-start' | 'left-end' | 'auto' | 'auto-start' | 'auto-end';
    /** the number of milliseconds to delay showing the tooltip once the user's mouse enters this component * */
    showDelay?: number;
    useClickInsteadOfHover?: boolean;
    /** whether to hide tooltip from dom */
    hideTooltip?: boolean;
    /** callback run when tooltip shows */
    onShow?: FunctionGeneric;
    /** callback run when tooltip hides */
    onHide?: FunctionGeneric;
    /** focus the tooltip on opening, useful for dropdowns, contextmenus, etc */
    focusOnOpen?: boolean;
    /** Stop propagation of the popper click events */
    stopPopperClickPropagation?: boolean;
    /** Don't use show/hide animations (sets transition-duration to 1ms) */
    noAnimations?: boolean;
}
export declare const Tooltip: React.ForwardRefExoticComponent<Pick<TooltipProps, "style" | "aria-label" | "className" | "id" | "children" | "role" | "onClick" | "onKeyUp" | "onKeyDown" | "key" | "innerRef" | "onMouseDown" | "onMouseUp" | "onBlur" | "onFocus" | "tabIndex" | "aria-checked" | "aria-labelledby" | "aria-expanded" | "aria-controls" | "aria-describedby" | "onContextMenu" | "onDoubleClick" | "onMouseEnter" | "onMouseLeave" | "position" | "content" | "forceShow" | "useClickInsteadOfHover" | "popperArrowModifier" | "popperOffsetModifier" | "hideDelay" | "hideArrow" | "popperContainerClassName" | "popperVisualContainerClassName" | "showDelay" | "hideTooltip" | "onShow" | "onHide" | "focusOnOpen" | "stopPopperClickPropagation" | "noAnimations"> & React.RefAttributes<HTMLElement>>;
export declare const hideTooltip: (id: string) => void;
export declare const showTooltip: (id: string) => void;
//# sourceMappingURL=Tooltip.d.ts.map